@@ -29,6 +29,7 @@ class Instrument(db.Model):
     users_can_view_log_entries = db.Column(db.Boolean, nullable=False, default=False)
     notes = db.Column(db.String, nullable=False, default='')
     notes_as_html = db.Column(db.String, nullable=True, default=None)
+    create_log_entry_default = db.Column(db.Boolean, nullable=False, default=False)
 
     def __init__(
             self,
@@ -39,6 +40,7 @@ class Instrument(db.Model):
             users_can_view_log_entries: bool = False,
             notes: str = '',
             notes_as_html: typing.Optional[str] = None,
+            create_log_entry_default: bool = False
     ):
         self.name = name
         self.description = description
@@ -47,6 +49,7 @@ class Instrument(db.Model):
         self.users_can_view_log_entries = users_can_view_log_entries
         self.notes = notes
         self.notes_as_html = notes_as_html
+        self.create_log_entry_default = create_log_entry_default
 
     def __eq__(self, other):
         return (
@@ -58,6 +61,7 @@ class Instrument(db.Model):
             self.users_can_view_log_entries == other.users_can_view_log_entries and
             self.notes == other.notes and
             self.notes_as_html == other.notes_as_html and
+            self.create_log_entry_default == other.create_log_entry_default and
             self.responsible_users == other.responsible_users
         )
 
